# WARNING - Generated by {fusen} from dev/flat_full.Rmd: do not edit by hand


#' Root Mean Squared Error (RMSE)
#'
#' Calculates the root mean squared error (RMSE) between two vectors.
#'
#' @param y Vector of actual values.
#' @param y_hat Vector of estimates/predicted values.
#' @return RMSE value.
#' @export
rmse <- function(y, y_hat) {
  if (length(y) != length(y_hat)) {
    stop("RMSE: Vectors y and y_hat must have the same length.")
  }
  
  rmse <- sqrt(mean((y - y_hat)^2, na.rm = T))
  return(rmse)
}




#' Compute RMSE values on grouped data
#'
#' This function takes a data frame, performs RMSE between estimate and actual values on specified grouping variables,
#'
#' @param data A data frame containing the variables 'actual' and 'estimate' for regression.
#' @param grouping_by A character vector specifying the grouping variables
#' @return A data frame with columns 'from', 'term', and 'RMSE' representing the grouping variables
#' and the corresponding RMSE values.
#' @export
#' @examples
#' data <- data.frame(from = c("A", "A", "A", "A"),
#'                    term = c("X", "Y", "X", "Y"),
#'                    actual = c(1, 2, 3, 4),
#'                    estimate = c(1.5, 2.5, 3.5, 4.5))
#' compute_rmse(data, grouping_by = c("from", "term"))
#'
#' @importFrom data.table data.table
compute_rmse <- function(data, grouping_by = c("from", "description")) {
  ## -- convert to data.table
  dat <- data.table::data.table(data)
  ## -- calculate the RMSE
  rmse_df <- as.data.frame( 
                dat[ , rmse(actual, estimate), 
                 by = grouping_by ]
            )
  names(rmse_df)[names(rmse_df) == "V1"] <- "RMSE"
  return(rmse_df)
}


